@@ -1,9 +1,10 @@
 import random as rm
 import time
 import webbrowser as web
-import requests
 import smtplib
 from email.mime.text import MIMEText
+
+import requests
 import mahjong
 from mahjong.tile import TilesConverter
 from mahjong.shanten import Shanten
@@ -17,10 +18,10 @@ def help():
     print(" torancell.bogo(int)")
     print(" torancell.wiki()")
     print(" torancell.weather()")
-    print(" torancell.mail(your mailaddress)")
+    print(" torancell.mail("your mailaddress")")
     print(" list = torancell.handgen()")
     print(" torancell.shantenquiz()")
-    print(" torancell.tenhou()")
+    print(" torancell.tenhou(step)")
     
 def red():
     str = "かたい カラに つつまれているが なかみは やわらかいので つよい こうげきには たえられない。"
@@ -460,7 +461,7 @@ def globalvar():
     sous = []
     pins = []
     jihai = []
-def ttt(i):
+def waruyon(i):
     return i//4+1
 def intmahjong(i):
     if i<=9:
@@ -495,6 +496,7 @@ def intmahjong(i):
         return "tyu"
 def handgen(t=13):
     globalvar()
+    global i #山
     i = list(range(1,136))
     rm.shuffle(i)
     l = list()
@@ -502,13 +504,12 @@ def handgen(t=13):
         l.append(i.pop())
         t = t-1
         l.sort()
-    inthand = list(map(ttt,l))
+    inthand = list(map(waruyon,l))
     global hand
     hand = list(map(intmahjong,inthand))
     return hand
 
-def shantenquiz():
-    print(handgen())
+def shanck():
     jmans=''.join(mans)
     jsous=''.join(sous)
     jpins=''.join(pins)
@@ -516,13 +517,18 @@ def shantenquiz():
     shanten = Shanten()
     tiles = TilesConverter.string_to_34_array(man=jmans,sou=jsous,pin=jpins,honors=jjihai)
     result = shanten.calculate_shanten(tiles)
+    return result
+
+def shantenquiz():
+    print(handgen())
+    result = shanck()
     chanten = int(input("How many shanten? : "))
     if result == chanten:
         print(True)
     else:
         print("False, correct answer is "+str(result))
 
-def tenhou():
+def tenhou(step=1000):
     i = 1
     while 1:
         handgen(14)
@@ -535,18 +541,15 @@ def tenhou():
         result = shanten.calculate_shanten(tiles)
         if result==-1:
                 if len(jihai)<4:
-                    print(str(hand)+"\t\t"+str(result)+" 天和 "+str(i)+"局目")
+                    print(str(hand)+"\t\t 天和 "+str(i)+"局目")
                     return
                 else:
-                    print(str(hand)+"\t"+str(result)+" 天和 "+str(i)+"局目")
+                    print(str(hand)+"\t 天和 "+str(i)+"局目")
                     return
         else:
-            if i%1000==0:
+            if i%step==0:
                 if len(jihai)<4:
                     print(str(hand)+"\t\t"+str(result)+"向牌 "+str(i)+"局目")
                 else:
                     print(str(hand)+"\t"+str(result)+"向牌 "+str(i)+"局目")
-        i = i+1
-
-
-
+        i = i+1
\ No newline at end of file
